# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 63.0.0-v202310120111-BETA
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ContextOpaqueInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data': 'str',
        'datum_id': 'str',
        'key': 'str'
    }

    attribute_map = {
        'data': 'data',
        'datum_id': 'datumId',
        'key': 'key'
    }

    def __init__(self, data=None, datum_id=None, key=None):
        """
        ContextOpaqueInputV1 - a model defined in Swagger
        """

        self._data = None
        self._datum_id = None
        self._key = None

        if data is not None:
          self.data = data
        if datum_id is not None:
          self.datum_id = datum_id
        if key is not None:
          self.key = key

    @property
    def data(self):
        """
        Gets the data of this ContextOpaqueInputV1.
        The data for this piece of context. If the data is binary it must first be base64 encoded

        :return: The data of this ContextOpaqueInputV1.
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """
        Sets the data of this ContextOpaqueInputV1.
        The data for this piece of context. If the data is binary it must first be base64 encoded

        :param data: The data of this ContextOpaqueInputV1.
        :type: str
        """

        self._data = data

    @property
    def datum_id(self):
        """
        Gets the datum_id of this ContextOpaqueInputV1.
        If provided, the ID of a more specific aspect of the Item to associate with the opaque context, such as the ID of a capsule

        :return: The datum_id of this ContextOpaqueInputV1.
        :rtype: str
        """
        return self._datum_id

    @datum_id.setter
    def datum_id(self, datum_id):
        """
        Sets the datum_id of this ContextOpaqueInputV1.
        If provided, the ID of a more specific aspect of the Item to associate with the opaque context, such as the ID of a capsule

        :param datum_id: The datum_id of this ContextOpaqueInputV1.
        :type: str
        """

        self._datum_id = datum_id

    @property
    def key(self):
        """
        Gets the key of this ContextOpaqueInputV1.
        The identifier of the data. This will uniquely identify this piece of opaque context for a specific Item or datum

        :return: The key of this ContextOpaqueInputV1.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this ContextOpaqueInputV1.
        The identifier of the data. This will uniquely identify this piece of opaque context for a specific Item or datum

        :param key: The key of this ContextOpaqueInputV1.
        :type: str
        """

        self._key = key

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ContextOpaqueInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
